List:Commits« Previous MessageNext Message »
From:Marc Alff Date:October 23 2008 6:22pm
Subject:bzr commit into mysql-6.0-perf branch (marc.alff:2716)
View as plain text  
#At file:///home/malff/BZR-TREE/mysql-6.0-perf/

 2716 Marc Alff	2008-10-23
      Build cleanup
modified:
  configure.in
  include/mysql/psi.h
  include/mysql/psi_abi_v1.h.pp
  include/mysql/psi_abi_v2.h.pp
  storage/innobase/handler/ha_innodb.cc
  storage/perfschema/plug.in
  storage/perfschema/psm_sync_info.cc
  storage/perfschema/psm_sync_info.h

=== modified file 'configure.in'
--- a/configure.in	2008-10-18 00:52:29 +0000
+++ b/configure.in	2008-10-23 18:22:09 +0000
@@ -1770,17 +1770,6 @@ case "$with_atomic_ops" in
    *) AC_MSG_ERROR(["$with_atomic_ops" is not a valid value for --with-atomic-ops]) ;;
 esac
 
-AC_ARG_WITH([performance-schema-interface],
-    AC_HELP_STRING([--with-performance-schema-interface],
-    [Compile with the performance schema interface mysql/psi.h (default is enabled)]),
-    [with_psi=$withval], [with_psi=yes])
-
-if test "$with_psi" != "no"
-then
-  AC_DEFINE([HAVE_PSI_INTERFACE], [1],
-            [Define to 1 if you want to use mysql/psi.h])
-fi
-
 AC_CACHE_CHECK([whether the compiler provides atomic builtins],
                [mysql_cv_gcc_atomic_builtins], [AC_TRY_RUN([
   int main()

=== modified file 'include/mysql/psi.h'
--- a/include/mysql/psi.h	2008-10-22 22:21:54 +0000
+++ b/include/mysql/psi.h	2008-10-23 18:22:09 +0000
@@ -25,9 +25,9 @@ struct PSI_thread;
 struct PSI_locker;
 
 /* Opaque key */
-typedef int PSI_mutex_key;
-typedef int PSI_rwlock_key;
-typedef int PSI_cond_key;
+typedef unsigned int PSI_mutex_key;
+typedef unsigned int PSI_rwlock_key;
+typedef unsigned int PSI_cond_key;
 
 #ifdef USE_PSI_1
 #define HAVE_PSI_1

=== modified file 'include/mysql/psi_abi_v1.h.pp'
--- a/include/mysql/psi_abi_v1.h.pp	2008-10-22 22:21:54 +0000
+++ b/include/mysql/psi_abi_v1.h.pp	2008-10-23 18:22:09 +0000
@@ -8,9 +8,9 @@ struct PSI_rwlock;
 struct PSI_cond;
 struct PSI_thread;
 struct PSI_locker;
-typedef int PSI_mutex_key;
-typedef int PSI_rwlock_key;
-typedef int PSI_cond_key;
+typedef unsigned int PSI_mutex_key;
+typedef unsigned int PSI_rwlock_key;
+typedef unsigned int PSI_cond_key;
 struct PSI_mutex_info_v1
 {
   PSI_mutex_key *m_key;

=== modified file 'include/mysql/psi_abi_v2.h.pp'
--- a/include/mysql/psi_abi_v2.h.pp	2008-10-16 00:25:49 +0000
+++ b/include/mysql/psi_abi_v2.h.pp	2008-10-23 18:22:09 +0000
@@ -8,9 +8,9 @@ struct PSI_rwlock;
 struct PSI_cond;
 struct PSI_thread;
 struct PSI_locker;
-typedef int PSI_mutex_key;
-typedef int PSI_rwlock_key;
-typedef int PSI_cond_key;
+typedef unsigned int PSI_mutex_key;
+typedef unsigned int PSI_rwlock_key;
+typedef unsigned int PSI_cond_key;
 struct PSI_v2
 {
   int placeholder;

=== modified file 'storage/innobase/handler/ha_innodb.cc'
--- a/storage/perfschema/plug.in	2008-10-22 22:21:54 +0000
+++ b/storage/perfschema/plug.in	2008-10-23 18:22:09 +0000
@@ -19,6 +19,13 @@ AC_DEFINE([HAVE_PERFORMANCE_SCHEMA], [1]
           [Performance schema implementation])
 
 dnl -------------------------------------------------------------------------
+dnl HAVE_PSI_INTERFACE
+dnl -------------------------------------------------------------------------
+
+AC_DEFINE([HAVE_PSI_INTERFACE], [1],
+          [Performance schema instrumentation interface])
+
+dnl -------------------------------------------------------------------------
 dnl PSM_MAX_SYNC_INFO
 dnl -------------------------------------------------------------------------
 

=== modified file 'storage/perfschema/psm_sync_info.cc'
--- a/storage/perfschema/psm_sync_info.cc	2008-10-22 22:21:54 +0000
+++ b/storage/perfschema/psm_sync_info.cc	2008-10-23 18:22:09 +0000
@@ -53,7 +53,7 @@ PSM_sync_key register_sync_info(PSM_sync
                                 const char* name,
                                 int flags)
 {
-  int index;
+  uint index;
   PSM_sync_info *entry;
 
 #ifndef DBUG_OFF
@@ -105,7 +105,7 @@ PSM_sync_key register_sync_info(PSM_sync
 
 PSM_sync_info *find_sync_info(PSM_sync_key key)
 {
-  if ((key <= 0) || (key > sync_info_count))
+  if ((key == 0) || (key > sync_info_count))
     return 0;
 
   return & sync_info_array[key-1];

=== modified file 'storage/perfschema/psm_sync_info.h'
--- a/storage/perfschema/psm_sync_info.h	2008-10-22 22:21:54 +0000
+++ b/storage/perfschema/psm_sync_info.h	2008-10-23 18:22:09 +0000
@@ -7,7 +7,7 @@
 
 #include "mysql/psi.h"
 
-typedef int PSM_sync_key;
+typedef unsigned int PSM_sync_key;
 
 enum PSM_sync_type
 {

Thread
bzr commit into mysql-6.0-perf branch (marc.alff:2716) Marc Alff23 Oct
--- a/storage/innobase/handler/ha_innodb.cc	2008-10-01 12:02:28 +0000
+++ b/storage/innobase/handler/ha_innodb.cc	2008-10-23 18:22:09 +0000
@@ -41,9 +41,9 @@ have disabled the InnoDB inlining in thi
 #include <mysql/plugin.h>
 
 #ifndef MYSQL_SERVER
 /* This is needed because of Bug #3596.  Let us hope that pthread_mutex_t
 is defined the same in both builds: the MySQL server and the InnoDB plugin. */
-extern pthread_mutex_t LOCK_thread_count;
+extern mysql_mutex_t LOCK_thread_count;
 #endif /* MYSQL_SERVER */
 
 /** to protect innobase_open_files */
@@ -715,7 +715,7 @@ void
 innobase_mysql_prepare_print_arbitrary_thd(void)
 /*============================================*/
 {
-	pthread_mutex_lock(&LOCK_thread_count);
+	MYSQL_MUTEX_LOCK(&LOCK_thread_count);
 }
 
 /*****************************************************************
@@ -727,7 +727,7 @@ void
 innobase_mysql_end_print_arbitrary_thd(void)
 /*========================================*/
 {
-	pthread_mutex_unlock(&LOCK_thread_count);
+	MYSQL_MUTEX_UNLOCK(&LOCK_thread_count);
 }
 
 /*****************************************************************
@@ -41,9 +41,9 @@ have disabled the InnoDB inlining in thi
 
 #ifndef MYSQL_SERVER
-/* This is needed because of Bug #3596.  Let us hope that pthread_mutex_t
+/* This is needed because of Bug #3596.  Let us hope that mysql_mutex_t
 is defined the same in both builds: the MySQL server and the InnoDB plugin. */

=== modified file 'storage/perfschema/plug.in'